using System;
using System.Collections.Generic;
using System.Text;
using System.Xml.Serialization;
using System.Xml;

namespace XmlDataContractExample
{
    public partial class BusinessObjectUpdateBatch
    {

        /// <summary>
        /// Initializes a new instance of the <see cref="BusinessObjectUpdateBatch"/> class.
        /// </summary>
        public BusinessObjectUpdateBatch()
        {
        }


        /// <summary>
        /// Initializes a new instance of the <see cref="BusinessObjectUpdateBatch"/> class.
        /// </summary>
        /// <param name="businessObjects">The business objects.</param>
        public BusinessObjectUpdateBatch(List<BusinessObject> businessObjects)
        {
            BusinessObjectUpdateBatchRecord[] recordsToUpdate = new BusinessObjectUpdateBatchRecord[businessObjects.Count];
            businessObjects.ForEach(delegate (BusinessObject bo)
            {
                BusinessObjectUpdateBatchRecord record = new BusinessObjectUpdateBatchRecord(bo);
                recordsToUpdate[businessObjects.IndexOf(bo)] = record;
            });
            this.Record = recordsToUpdate;
        }

        /// <summary>
        /// Serializes the specified batch to a string.
        /// </summary>
        /// <param name="batchToSerialize">The batch to serialize.</param>
        /// <returns></returns>
        public static string Serialize(BusinessObjectUpdateBatch batchToSerialize)
        {
            XmlSerializer serializer = new XmlSerializer(typeof(BusinessObjectUpdateBatch));
            StringBuilder sb = new StringBuilder();
            using (XmlWriter writer = XmlWriter.Create(sb))
            {
                serializer.Serialize(writer, batchToSerialize);
                return sb.ToString();
            }
        }
    }

    public partial class BusinessObjectUpdateBatchRecord
    {

        /// <summary>
        /// Initializes a new instance of the <see cref="BusinessObjectUpdateBatchRecord"/> class.
        /// </summary>
        public BusinessObjectUpdateBatchRecord()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="BusinessObjectUpdateBatchRecord"/> class.
        /// </summary>
        public BusinessObjectUpdateBatchRecord(BusinessObject bo)
        {
            this.idField = bo.Id;
            this.text1Field = bo.SomeTextValue;
            this.text2Field = bo.SomeOtherTextValue;
        }


    }
}
